==> haskell-tagged-0.8.5-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tagged.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagged
version: 0.8.5
id: tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
key: tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
license: BSD-3-Clause
copyright: 2009-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/tagged
synopsis: Haskell 98 phantom types to avoid unsafely passing dummy arguments
description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments
category: Data, Phantom Types
abi: a77bb2a04ac30650821b1fe6972fa094
exposed: True
exposed-modules:
    Data.Proxy.TH Data.Tagged
import-dirs: /usr/lib/ghc-8.4.3/site-local/tagged-0.8.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/tagged-0.8.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tagged-0.8.5
hs-libraries: HStagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
depends:
    base-4.11.1.0 template-haskell-2.13.0.0 deepseq-1.4.3.0
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
haddock-interfaces: /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html: /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagged-0.8.6-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tagged.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagged
version: 0.8.6
id: tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
key: tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
license: BSD-3-Clause
copyright: 2009-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/tagged
synopsis: Haskell 98 phantom types to avoid unsafely passing dummy arguments
description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments.
category: Data, Phantom Types
abi: 92d44612a64675b8cba7ce44e507a395
exposed: True
exposed-modules:
    Data.Proxy.TH Data.Tagged
import-dirs: /usr/lib/ghc-8.4.3/site-local/tagged-0.8.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/tagged-0.8.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tagged-0.8.6
hs-libraries: HStagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
depends:
    base-4.11.1.0 template-haskell-2.13.0.0 deepseq-1.4.3.0
    transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html: /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
